import { Component, h, Host, Element, State } from '@stencil/core';
import { ElementType } from '../../model/PaymentElementUpdateEvent';
import { COUNTRIES } from '../../utils/countries';
export class MadPaymentCreditCardPaymentElement {
  constructor() {
    this.cardData = {
      complete: false,
      invalid: false,
      invalidFields: []
    };
  }
  componentDidLoad() {
    if (this.countrySelect) {
      this.countrySelect.setOptions(COUNTRIES);
    }
  }
  handleElementUpdate(e, elementType) {
    const { detail } = e;
    switch (elementType) {
      case ElementType.CREDIT_CARD_NUMBER:
        let cardEvent = detail;
        if (cardEvent.cardType && cardEvent.cardType.length === 1)
          this.cardData.cardBrand = cardEvent.cardType[0];
        this.cardData.cardNumber = cardEvent.value;
        break;
      case ElementType.SECURITY_CODE:
        this.cardData.cardSecurityCode = detail.value;
        break;
      default:
        console.log('fall through');
    }
  }
  render() {
    return (h(Host, null,
      h("div", { class: "payment-row" },
        h("mad-payment-input", { placeholder: "John Doe", label: "Cardholer name", class: "text-input", name: "Name" })),
      h("div", { class: "payment-row" },
        h("mad-payment-card-input", { class: "text-input", label: "Card Number", placeholder: "0000 0000 0000 0000", id: "card", onUpdate: (e) => this.handleElementUpdate(e, ElementType.CREDIT_CARD_NUMBER) })),
      h("div", { class: "payment-row" },
        h("mad-payment-expiration-input", { label: "Expiration", placeholder: "01 / 22", class: "text-input half" }),
        h("mad-payment-cvv-input", { placeholder: "123", label: "Security Code", class: "text-input half", name: "security-code", max: 4, id: "security-code", onUpdate: (e) => this.handleElementUpdate(e, ElementType.SECURITY_CODE) })),
      h("div", { class: "payment-row" },
        h("mad-payment-select", { label: "Country", id: "select", class: "text-input half", ref: el => this.countrySelect = el }),
        h("mad-payment-input", { placeholder: "33714", label: "Zipcode", class: "text-input half", name: "zipcode", max: 5 }))));
  }
  static get is() { return "mad-payment-credit-card-payment-element"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["credit-card-payment-element.css"]
  }; }
  static get styleUrls() { return {
    "$": ["credit-card-payment-element.css"]
  }; }
  static get states() { return {
    "cardData": {}
  }; }
  static get elementRef() { return "element"; }
}
