import { Component, Prop, h, Host, Event, State } from '@stencil/core';
export class MadPaymentInput {
  constructor() {
    this.valid = true;
  }
  handleInput(e) {
    const { target: { value } } = e;
    this.valid = this.isValid(value);
    const updateEvent = {
      valid: this.valid,
      value: value,
      complete: true
    };
    this.update.emit(updateEvent);
    this.payInput.emit(e);
  }
  isValid(value) {
    if (this.validationExpression) {
      return this.validationExpression.test(value);
    }
  }
  render() {
    return (h(Host, null,
      this.label && h("div", { class: "input-label" },
        h("label", { htmlFor: this.name }, this.label)),
      h("div", { class: "input-field" },
        h("input", { type: "text", placeholder: this.placeholder, value: this.value, maxLength: this.max, onKeyDown: (e) => { this.payKeyDown.emit(e); }, onKeyUp: (e) => { this.payKeyUp.emit(e); }, onKeyPress: (e) => { this.payKeyPress.emit(e); }, onInput: (e) => this.handleInput(e) }),
        h("div", { class: "icons" },
          h("slot", { name: "icons" })))));
  }
  static get is() { return "mad-payment-input"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["input.css"]
  }; }
  static get styleUrls() { return {
    "$": ["input.css"]
  }; }
  static get properties() { return {
    "placeholder": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Input placeholder text"
      },
      "attribute": "placeholder",
      "reflect": false
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Label text is optional, if present label is dplayed"
      },
      "attribute": "label",
      "reflect": false
    },
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Input name"
      },
      "attribute": "name",
      "reflect": false
    },
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Input value"
      },
      "attribute": "value",
      "reflect": false
    },
    "max": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Input max length"
      },
      "attribute": "max",
      "reflect": false
    },
    "validationExpression": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "RegExp",
        "resolved": "RegExp",
        "references": {
          "RegExp": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": ""
      }
    }
  }; }
  static get states() { return {
    "valid": {}
  }; }
  static get events() { return [{
      "method": "payInput",
      "name": "payInput",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "InputEvent",
        "resolved": "InputEvent",
        "references": {
          "InputEvent": {
            "location": "global"
          }
        }
      }
    }, {
      "method": "payKeyUp",
      "name": "payKeyUp",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "KeyboardEvent",
        "resolved": "KeyboardEvent",
        "references": {
          "KeyboardEvent": {
            "location": "global"
          }
        }
      }
    }, {
      "method": "payKeyDown",
      "name": "payKeyDown",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "KeyboardEvent",
        "resolved": "KeyboardEvent",
        "references": {
          "KeyboardEvent": {
            "location": "global"
          }
        }
      }
    }, {
      "method": "payKeyPress",
      "name": "payKeyPress",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "KeyboardEvent",
        "resolved": "KeyboardEvent",
        "references": {
          "KeyboardEvent": {
            "location": "global"
          }
        }
      }
    }, {
      "method": "update",
      "name": "update",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "PaymentElementUpdateEvent",
        "resolved": "{ valid: boolean; value: string; complete: boolean; errors?: InputError[]; }",
        "references": {
          "PaymentElementUpdateEvent": {
            "location": "import",
            "path": "../../model/PaymentElementUpdateEvent"
          }
        }
      }
    }]; }
}
