import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$7 } from './card-icon.js';
import { d as defineCustomElement$6 } from './amex.js';
import { d as defineCustomElement$5 } from './discover.js';
import { d as defineCustomElement$4 } from './mastercard.js';
import { d as defineCustomElement$3 } from './security-code.js';
import { d as defineCustomElement$2 } from './visa.js';
import { d as defineCustomElement$1 } from './input.js';

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function createCommonjsModule(fn, basedir, module) {
	return module = {
		path: basedir,
		exports: {},
		require: function (path, base) {
			return commonjsRequire();
		}
	}, fn(module, module.exports), module.exports;
}

function commonjsRequire () {
	throw new Error('Dynamic requires are not currently supported by @rollup/plugin-commonjs');
}

var cardTypes = {
    visa: {
        niceType: "Visa",
        type: "visa",
        patterns: [4],
        gaps: [4, 8, 12],
        lengths: [16, 18, 19],
        code: {
            name: "CVV",
            size: 3,
        },
    },
    mastercard: {
        niceType: "Mastercard",
        type: "mastercard",
        patterns: [[51, 55], [2221, 2229], [223, 229], [23, 26], [270, 271], 2720],
        gaps: [4, 8, 12],
        lengths: [16],
        code: {
            name: "CVC",
            size: 3,
        },
    },
    "american-express": {
        niceType: "American Express",
        type: "american-express",
        patterns: [34, 37],
        gaps: [4, 10],
        lengths: [15],
        code: {
            name: "CID",
            size: 4,
        },
    },
    "diners-club": {
        niceType: "Diners Club",
        type: "diners-club",
        patterns: [[300, 305], 36, 38, 39],
        gaps: [4, 10],
        lengths: [14, 16, 19],
        code: {
            name: "CVV",
            size: 3,
        },
    },
    discover: {
        niceType: "Discover",
        type: "discover",
        patterns: [6011, [644, 649], 65],
        gaps: [4, 8, 12],
        lengths: [16, 19],
        code: {
            name: "CID",
            size: 3,
        },
    },
    jcb: {
        niceType: "JCB",
        type: "jcb",
        patterns: [2131, 1800, [3528, 3589]],
        gaps: [4, 8, 12],
        lengths: [16, 17, 18, 19],
        code: {
            name: "CVV",
            size: 3,
        },
    },
    unionpay: {
        niceType: "UnionPay",
        type: "unionpay",
        patterns: [
            620,
            [624, 626],
            [62100, 62182],
            [62184, 62187],
            [62185, 62197],
            [62200, 62205],
            [622010, 622999],
            622018,
            [622019, 622999],
            [62207, 62209],
            [622126, 622925],
            [623, 626],
            6270,
            6272,
            6276,
            [627700, 627779],
            [627781, 627799],
            [6282, 6289],
            6291,
            6292,
            810,
            [8110, 8131],
            [8132, 8151],
            [8152, 8163],
            [8164, 8171],
        ],
        gaps: [4, 8, 12],
        lengths: [14, 15, 16, 17, 18, 19],
        code: {
            name: "CVN",
            size: 3,
        },
    },
    maestro: {
        niceType: "Maestro",
        type: "maestro",
        patterns: [
            493698,
            [500000, 504174],
            [504176, 506698],
            [506779, 508999],
            [56, 59],
            63,
            67,
            6,
        ],
        gaps: [4, 8, 12],
        lengths: [12, 13, 14, 15, 16, 17, 18, 19],
        code: {
            name: "CVC",
            size: 3,
        },
    },
    elo: {
        niceType: "Elo",
        type: "elo",
        patterns: [
            401178,
            401179,
            438935,
            457631,
            457632,
            431274,
            451416,
            457393,
            504175,
            [506699, 506778],
            [509000, 509999],
            627780,
            636297,
            636368,
            [650031, 650033],
            [650035, 650051],
            [650405, 650439],
            [650485, 650538],
            [650541, 650598],
            [650700, 650718],
            [650720, 650727],
            [650901, 650978],
            [651652, 651679],
            [655000, 655019],
            [655021, 655058],
        ],
        gaps: [4, 8, 12],
        lengths: [16],
        code: {
            name: "CVE",
            size: 3,
        },
    },
    mir: {
        niceType: "Mir",
        type: "mir",
        patterns: [[2200, 2204]],
        gaps: [4, 8, 12],
        lengths: [16, 17, 18, 19],
        code: {
            name: "CVP2",
            size: 3,
        },
    },
    hiper: {
        niceType: "Hiper",
        type: "hiper",
        patterns: [637095, 63737423, 63743358, 637568, 637599, 637609, 637612],
        gaps: [4, 8, 12],
        lengths: [16],
        code: {
            name: "CVC",
            size: 3,
        },
    },
    hipercard: {
        niceType: "Hipercard",
        type: "hipercard",
        patterns: [606282],
        gaps: [4, 8, 12],
        lengths: [16],
        code: {
            name: "CVC",
            size: 3,
        },
    },
};
var cardTypes_1 = cardTypes;

var clone_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
exports.clone = void 0;
function clone(originalObject) {
    if (!originalObject) {
        return null;
    }
    return JSON.parse(JSON.stringify(originalObject));
}
exports.clone = clone;
});

var matches_1 = createCommonjsModule(function (module, exports) {
/*
 * Adapted from https://github.com/polvo-labs/card-type/blob/aaab11f80fa1939bccc8f24905a06ae3cd864356/src/cardType.js#L37-L42
 * */
Object.defineProperty(exports, "__esModule", { value: true });
exports.matches = void 0;
function matchesRange(cardNumber, min, max) {
    var maxLengthToCheck = String(min).length;
    var substr = cardNumber.substr(0, maxLengthToCheck);
    var integerRepresentationOfCardNumber = parseInt(substr, 10);
    min = parseInt(String(min).substr(0, substr.length), 10);
    max = parseInt(String(max).substr(0, substr.length), 10);
    return (integerRepresentationOfCardNumber >= min &&
        integerRepresentationOfCardNumber <= max);
}
function matchesPattern(cardNumber, pattern) {
    pattern = String(pattern);
    return (pattern.substring(0, cardNumber.length) ===
        cardNumber.substring(0, pattern.length));
}
function matches(cardNumber, pattern) {
    if (Array.isArray(pattern)) {
        return matchesRange(cardNumber, pattern[0], pattern[1]);
    }
    return matchesPattern(cardNumber, pattern);
}
exports.matches = matches;
});

var addMatchingCardsToResults_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
exports.addMatchingCardsToResults = void 0;


function addMatchingCardsToResults(cardNumber, cardConfiguration, results) {
    var i, patternLength;
    for (i = 0; i < cardConfiguration.patterns.length; i++) {
        var pattern = cardConfiguration.patterns[i];
        if (!matches_1.matches(cardNumber, pattern)) {
            continue;
        }
        var clonedCardConfiguration = clone_1.clone(cardConfiguration);
        if (Array.isArray(pattern)) {
            patternLength = String(pattern[0]).length;
        }
        else {
            patternLength = String(pattern).length;
        }
        if (cardNumber.length >= patternLength) {
            clonedCardConfiguration.matchStrength = patternLength;
        }
        results.push(clonedCardConfiguration);
        break;
    }
}
exports.addMatchingCardsToResults = addMatchingCardsToResults;
});

var isValidInputType_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidInputType = void 0;
function isValidInputType(cardNumber) {
    return typeof cardNumber === "string" || cardNumber instanceof String;
}
exports.isValidInputType = isValidInputType;
});

var findBestMatch_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
exports.findBestMatch = void 0;
function hasEnoughResultsToDetermineBestMatch(results) {
    var numberOfResultsWithMaxStrengthProperty = results.filter(function (result) { return result.matchStrength; }).length;
    /*
     * if all possible results have a maxStrength property that means the card
     * number is sufficiently long enough to determine conclusively what the card
     * type is
     * */
    return (numberOfResultsWithMaxStrengthProperty > 0 &&
        numberOfResultsWithMaxStrengthProperty === results.length);
}
function findBestMatch(results) {
    if (!hasEnoughResultsToDetermineBestMatch(results)) {
        return null;
    }
    return results.reduce(function (bestMatch, result) {
        if (!bestMatch) {
            return result;
        }
        /*
         * If the current best match pattern is less specific than this result, set
         * the result as the new best match
         * */
        if (Number(bestMatch.matchStrength) < Number(result.matchStrength)) {
            return result;
        }
        return bestMatch;
    });
}
exports.findBestMatch = findBestMatch;
});

var __assign = (commonjsGlobal && commonjsGlobal.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};





var customCards = {};
var cardNames = {
    VISA: "visa",
    MASTERCARD: "mastercard",
    AMERICAN_EXPRESS: "american-express",
    DINERS_CLUB: "diners-club",
    DISCOVER: "discover",
    JCB: "jcb",
    UNIONPAY: "unionpay",
    MAESTRO: "maestro",
    ELO: "elo",
    MIR: "mir",
    HIPER: "hiper",
    HIPERCARD: "hipercard",
};
var ORIGINAL_TEST_ORDER = [
    cardNames.VISA,
    cardNames.MASTERCARD,
    cardNames.AMERICAN_EXPRESS,
    cardNames.DINERS_CLUB,
    cardNames.DISCOVER,
    cardNames.JCB,
    cardNames.UNIONPAY,
    cardNames.MAESTRO,
    cardNames.ELO,
    cardNames.MIR,
    cardNames.HIPER,
    cardNames.HIPERCARD,
];
var testOrder = clone_1.clone(ORIGINAL_TEST_ORDER);
function findType(cardType) {
    return customCards[cardType] || cardTypes_1[cardType];
}
function getAllCardTypes() {
    return testOrder.map(function (cardType) { return clone_1.clone(findType(cardType)); });
}
function getCardPosition(name, ignoreErrorForNotExisting) {
    if (ignoreErrorForNotExisting === void 0) { ignoreErrorForNotExisting = false; }
    var position = testOrder.indexOf(name);
    if (!ignoreErrorForNotExisting && position === -1) {
        throw new Error('"' + name + '" is not a supported card type.');
    }
    return position;
}
function creditCardType(cardNumber) {
    var results = [];
    if (!isValidInputType_1.isValidInputType(cardNumber)) {
        return results;
    }
    if (cardNumber.length === 0) {
        return getAllCardTypes();
    }
    testOrder.forEach(function (cardType) {
        var cardConfiguration = findType(cardType);
        addMatchingCardsToResults_1.addMatchingCardsToResults(cardNumber, cardConfiguration, results);
    });
    var bestMatch = findBestMatch_1.findBestMatch(results);
    if (bestMatch) {
        return [bestMatch];
    }
    return results;
}
creditCardType.getTypeInfo = function (cardType) {
    return clone_1.clone(findType(cardType));
};
creditCardType.removeCard = function (name) {
    var position = getCardPosition(name);
    testOrder.splice(position, 1);
};
creditCardType.addCard = function (config) {
    var existingCardPosition = getCardPosition(config.type, true);
    customCards[config.type] = config;
    if (existingCardPosition === -1) {
        testOrder.push(config.type);
    }
};
creditCardType.updateCard = function (cardType, updates) {
    var originalObject = customCards[cardType] || cardTypes_1[cardType];
    if (!originalObject) {
        throw new Error("\"" + cardType + "\" is not a recognized type. Use `addCard` instead.'");
    }
    if (updates.type && originalObject.type !== updates.type) {
        throw new Error("Cannot overwrite type parameter.");
    }
    var clonedCard = clone_1.clone(originalObject);
    clonedCard = __assign(__assign({}, clonedCard), updates);
    customCards[clonedCard.type] = clonedCard;
};
creditCardType.changeOrder = function (name, position) {
    var currentPosition = getCardPosition(name);
    testOrder.splice(currentPosition, 1);
    testOrder.splice(position, 0, name);
};
creditCardType.resetModifications = function () {
    testOrder = clone_1.clone(ORIGINAL_TEST_ORDER);
    customCards = {};
};
creditCardType.types = cardNames;
var dist = creditCardType;

const CreditCardInputErrorCodes = {
  UNKNOWN_BRAND: {
    errorCode: 31,
    errorDescription: 'Invalid card, brand unknown'
  },
  INCOMPLETE: {
    errorCode: 32,
    errorDescription: 'Incomplete card number'
  }
};

const cardInputCss = "";

const MadPaymentCardInput = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.update = createEvent(this, "update", 7);
    // DEFAULTS
    this.cardTypes = ['visa', 'mastercard', 'american-express', 'diners-club', 'discover', 'jcb', 'maestro'];
    this.baseCardTypes = ['visa', 'mastercard', 'american-express', 'discover'];
    this.defaultMax = 24;
    /**
     * The possible card types based on the input
     */
    this.possibleCards = ['visa', 'mastercard', 'american-express', 'discover'];
    /**
     * The max size of the input field
    */
    this.max = this.defaultMax;
  }
  handleChange(event) {
    event.preventDefault();
    const errors = [];
    const val = event.target.value.replace(/ /g, '');
    const cardTypes = dist(val);
    const allPossibleCards = cardTypes.filter(({ type }) => this.cardTypes.includes(type)).map(({ type }) => type);
    const updateEvent = {
      value: val,
      complete: false,
      cardType: allPossibleCards,
      valid: allPossibleCards.length !== 0,
    };
    this.possibleCards = allPossibleCards.filter((val) => this.baseCardTypes.includes(val));
    if (allPossibleCards.length === 1) {
      const { lengths: possibleLengths, type: cardType, code: { size: cvvSize } } = cardTypes[0];
      const [max] = possibleLengths.slice(-1);
      this.value = this.prettyCardNumber(val, cardType);
      this.max = max;
      updateEvent.complete = this.max === val.length;
      updateEvent.cvvMax = cvvSize;
    }
    else if (allPossibleCards.length === 0) {
      errors.push(CreditCardInputErrorCodes.UNKNOWN_BRAND);
    }
    else {
      errors.push(CreditCardInputErrorCodes.INCOMPLETE);
      this.max = this.defaultMax;
    }
    if (errors)
      updateEvent.errors = errors;
    this.update.emit(updateEvent);
  }
  handleKeyPress(e) {
    if (isNaN(e.key) || e.key.trim() === '' || this.isMax()) {
      e.preventDefault();
    }
  }
  isMax() {
    const val = this.value ? this.value.replace(/ /g, '') : '';
    return val.length === this.max;
  }
  prettyCardNumber(cardNumber, cardType) {
    var card = dist.getTypeInfo(cardType);
    if (card) {
      var offsets = [].concat(0, card.gaps, cardNumber.length);
      var components = [];
      for (var i = 0; offsets[i] < cardNumber.length; i++) {
        var start = offsets[i];
        var end = Math.min(offsets[i + 1], cardNumber.length);
        components.push(cardNumber.substring(start, end));
      }
      return components.join(" ");
    }
    return cardNumber;
  }
  render() {
    return (h(Host, null, h("mad-payment-input", { label: this.label, onPayKeyPress: ({ detail: e }) => { this.handleKeyPress(e); }, onPayInput: ({ detail: e }) => { this.handleChange(e); }, value: this.value, placeholder: this.placeholder }, this.baseCardTypes.map((card) => {
      return h("mad-payment-icon", { icon: card, class: `card-icon ${this.possibleCards.includes(card) ? 'visible' : ''}`, slot: "icons" });
    }))));
  }
  static get style() { return cardInputCss; }
}, [1, "mad-payment-card-input", {
    "placeholder": [1],
    "label": [1],
    "name": [1],
    "value": [32],
    "possibleCards": [32],
    "max": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mad-payment-card-input", "mad-payment-icon", "mad-payment-icon-amex", "mad-payment-icon-discover", "mad-payment-icon-mastercard", "mad-payment-icon-security-code", "mad-payment-icon-visa", "mad-payment-input"];
  components.forEach(tagName => { switch (tagName) {
    case "mad-payment-card-input":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MadPaymentCardInput);
      }
      break;
    case "mad-payment-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "mad-payment-icon-amex":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "mad-payment-icon-discover":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "mad-payment-icon-mastercard":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "mad-payment-icon-security-code":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "mad-payment-icon-visa":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "mad-payment-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { MadPaymentCardInput as M, defineCustomElement as d };
