import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$7 } from './card-icon.js';
import { d as defineCustomElement$6 } from './amex.js';
import { d as defineCustomElement$5 } from './discover.js';
import { d as defineCustomElement$4 } from './mastercard.js';
import { d as defineCustomElement$3 } from './security-code.js';
import { d as defineCustomElement$2 } from './visa.js';
import { d as defineCustomElement$1 } from './input.js';

const cvvInputCss = ":host .input-field{position:relative}:host .input-field>.card-icons{position:absolute;height:100%;display:flex;right:var(--spacing-small);top:0;align-items:center;justify-content:center;display:flex;gap:var(--spacing-xx-small)}:host .input-field>.card-icons>.card-icon{width:0;transition:all ease-in 200ms;height:100%;display:flex;align-items:center;opacity:0}:host .input-field>.card-icons>.card-icon.visible{width:30px;opacity:1}:host .input-field input{display:block;font-size:var(--size-font-5);border:var(--size-border-small) solid var(--color-border-default);padding:var(--spacing-small);border-radius:var(--radius-border-medium);color:var(--color-font-default);transition:all ease-in 200ms;box-sizing:border-box;width:100%}:host .input-field input.error{border:var(--size-border-small) solid var(--color-border-brand) !important;outline:var(--color-border-brand) auto 1px !important}:host .input-field input::placeholder{color:var(--color-font-light)}:host .input-field input:focus{border:var(--size-border-small) solid var(--color-border-active)}:host .input-field input:focus-visible{outline:var(--color-border-active) auto 1px}";

const MadPaymentCvvInput = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.update = createEvent(this, "update", 7);
    /**
     * Input placeholder text
     */
    this.placeholder = "";
    /**
     * Input name
     */
    this.name = "";
    this.value = "";
    this.type = "";
    this.max = 4;
  }
  handleChange(event) {
    event.preventDefault();
    const { target: { value } } = event;
    this.value = value;
    const updateEvent = {
      complete: value.length === this.max,
      value: value,
      valid: value.length === this.max
    };
    this.update.emit(updateEvent);
  }
  handleKeyPress(e) {
    if (isNaN(e.key) || e.key.trim() === '' || this.isMax()) {
      e.preventDefault();
    }
  }
  isMax() {
    const val = this.value ? this.value : '';
    return val.length === this.max;
  }
  render() {
    return (h(Host, null, h("mad-payment-input", { label: this.label, onPayKeyPress: ({ detail: e }) => { this.handleKeyPress(e); }, onPayInput: ({ detail: e }) => { this.handleChange(e); }, value: this.value, placeholder: this.placeholder }, h("mad-payment-icon", { icon: "security-code", class: `card-icon visible`, slot: "icons" }))));
  }
  static get style() { return cvvInputCss; }
}, [1, "mad-payment-cvv-input", {
    "placeholder": [1],
    "label": [1],
    "name": [1],
    "max": [2],
    "value": [32],
    "type": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mad-payment-cvv-input", "mad-payment-icon", "mad-payment-icon-amex", "mad-payment-icon-discover", "mad-payment-icon-mastercard", "mad-payment-icon-security-code", "mad-payment-icon-visa", "mad-payment-input"];
  components.forEach(tagName => { switch (tagName) {
    case "mad-payment-cvv-input":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MadPaymentCvvInput);
      }
      break;
    case "mad-payment-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "mad-payment-icon-amex":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "mad-payment-icon-discover":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "mad-payment-icon-mastercard":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "mad-payment-icon-security-code":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "mad-payment-icon-visa":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "mad-payment-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { MadPaymentCvvInput as M, defineCustomElement as d };
