import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';

const inputCss = ":host{display:block;font-family:var(--font-sans-serif);font-size:var(--size-font-4);color:var(--color-font-default);margin-bottom:var(--spacing-x-small)}:host .input-field{display:block;width:auto;position:relative}:host .input-label{display:block;margin-bottom:var(--spacing-x-small)}:host .input-field input{display:block;font-size:var(--size-font-5);border:var(--size-border-small) solid var(--color-border-default);padding:var(--spacing-small);border-radius:var(--radius-border-medium);color:var(--color-font-default);transition:all ease-in 200ms;box-sizing:border-box;width:100%}:host .input-field>.icons{position:absolute;height:100%;display:flex;right:var(--spacing-small);top:0;align-items:center;justify-content:center;display:flex;gap:var(--spacing-xx-small)}::slotted(mad-payment-icon){width:0;transition:all ease-in 200ms;height:100%;display:flex;align-items:center;opacity:0}::slotted(mad-payment-icon.visible){width:30px;opacity:1}:host .input-field input.error{border:var(--size-border-small) solid var(--color-border-brand)}:host .input-field input::placeholder{color:var(--color-font-light)}:host .input-field input:focus{border:var(--size-border-small) solid var(--color-border-active)}:host .input-field input:focus-visible{outline:var(--color-border-active) auto 1px}";

const MadPaymentInput = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.payInput = createEvent(this, "payInput", 7);
    this.payKeyUp = createEvent(this, "payKeyUp", 7);
    this.payKeyDown = createEvent(this, "payKeyDown", 7);
    this.payKeyPress = createEvent(this, "payKeyPress", 7);
    this.update = createEvent(this, "update", 7);
    this.valid = true;
  }
  handleInput(e) {
    const { target: { value } } = e;
    this.valid = this.isValid(value);
    const updateEvent = {
      valid: this.valid,
      value: value,
      complete: true
    };
    this.update.emit(updateEvent);
    this.payInput.emit(e);
  }
  isValid(value) {
    if (this.validationExpression) {
      return this.validationExpression.test(value);
    }
  }
  render() {
    return (h(Host, null, this.label && h("div", { class: "input-label" }, h("label", { htmlFor: this.name }, this.label)), h("div", { class: "input-field" }, h("input", { type: "text", placeholder: this.placeholder, value: this.value, maxLength: this.max, onKeyDown: (e) => { this.payKeyDown.emit(e); }, onKeyUp: (e) => { this.payKeyUp.emit(e); }, onKeyPress: (e) => { this.payKeyPress.emit(e); }, onInput: (e) => this.handleInput(e) }), h("div", { class: "icons" }, h("slot", { name: "icons" })))));
  }
  static get style() { return inputCss; }
}, [1, "mad-payment-input", {
    "placeholder": [1],
    "label": [1],
    "name": [1],
    "value": [1],
    "max": [2],
    "validationExpression": [16],
    "valid": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mad-payment-input"];
  components.forEach(tagName => { switch (tagName) {
    case "mad-payment-input":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MadPaymentInput);
      }
      break;
  } });
}

export { MadPaymentInput as M, defineCustomElement as d };
