import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$c } from './card-input.js';
import { d as defineCustomElement$b } from './cvv-input.js';
import { d as defineCustomElement$a } from './expiration-input.js';
import { d as defineCustomElement$9 } from './card-icon.js';
import { d as defineCustomElement$8 } from './amex.js';
import { d as defineCustomElement$7 } from './discover.js';
import { d as defineCustomElement$6 } from './mastercard.js';
import { d as defineCustomElement$5 } from './security-code.js';
import { d as defineCustomElement$4 } from './visa.js';
import { d as defineCustomElement$3 } from './input.js';
import { d as defineCustomElement$2 } from './select.js';

var ElementType;
(function (ElementType) {
  ElementType["CREDIT_CARD_NUMBER"] = "credit-card-number";
  ElementType["CARDHOLDER_NAME"] = "cardholder-name";
  ElementType["ZIPCODE"] = "zipcode";
  ElementType["COUNTRY"] = "country";
  ElementType["SECURITY_CODE"] = "security-code";
  ElementType["EXPIRATION_DATE"] = "expiration-date";
})(ElementType || (ElementType = {}));

const COUNTRIES = {
  "US": "United States",
  "AF": "Afghanistan",
  "AX": "Åland Islands",
  "AL": "Albania",
  "DZ": "Algeria",
  "AS": "American Samoa",
  "AD": "Andorra",
  "AO": "Angola",
  "AI": "Anguilla",
  "AQ": "Antarctica",
  "AG": "Antigua and Barbuda",
  "AR": "Argentina",
  "AM": "Armenia",
  "AW": "Aruba",
  "AU": "Australia",
  "AT": "Austria",
  "AZ": "Azerbaijan",
  "BS": "Bahamas",
  "BH": "Bahrain",
  "BD": "Bangladesh",
  "BB": "Barbados",
  "BY": "Belarus",
  "BE": "Belgium",
  "BZ": "Belize",
  "BJ": "Benin",
  "BM": "Bermuda",
  "BT": "Bhutan",
  "BO": "Bolivia",
  "BA": "Bosnia and Herzegovina",
  "BW": "Botswana",
  "BV": "Bouvet Island",
  "BR": "Brazil",
  "IO": "British Indian Ocean Territory",
  "BN": "Brunei Darussalam",
  "BG": "Bulgaria",
  "BF": "Burkina Faso",
  "BI": "Burundi",
  "KH": "Cambodia",
  "CM": "Cameroon",
  "CA": "Canada",
  "CV": "Cape Verde",
  "KY": "Cayman Islands",
  "CF": "Central African Republic",
  "TD": "Chad",
  "CL": "Chile",
  "CN": "China",
  "CX": "Christmas Island",
  "CC": "Cocos (Keeling) Islands",
  "CO": "Colombia",
  "KM": "Comoros",
  "CG": "Congo",
  "CD": "Congo, The Democratic Republic of the",
  "CK": "Cook Islands",
  "CR": "Costa Rica",
  "CI": "Cote D\'Ivoire",
  "HR": "Croatia",
  "CU": "Cuba",
  "CY": "Cyprus",
  "CZ": "Czech Republic",
  "DK": "Denmark",
  "DJ": "Djibouti",
  "DM": "Dominica",
  "DO": "Dominican Republic",
  "EC": "Ecuador",
  "EG": "Egypt",
  "SV": "El Salvador",
  "GQ": "Equatorial Guinea",
  "ER": "Eritrea",
  "EE": "Estonia",
  "ET": "Ethiopia",
  "FK": "Falkland Islands (Malvinas)",
  "FO": "Faroe Islands",
  "FJ": "Fiji",
  "FI": "Finland",
  "FR": "France",
  "GF": "French Guiana",
  "PF": "French Polynesia",
  "TF": "French Southern Territories",
  "GA": "Gabon",
  "GM": "Gambia",
  "GE": "Georgia",
  "DE": "Germany",
  "GH": "Ghana",
  "GI": "Gibraltar",
  "GR": "Greece",
  "GL": "Greenland",
  "GD": "Grenada",
  "GP": "Guadeloupe",
  "GU": "Guam",
  "GT": "Guatemala",
  "GG": "Guernsey",
  "GN": "Guinea",
  "GW": "Guinea-Bissau",
  "GY": "Guyana",
  "HT": "Haiti",
  "HM": "Heard Island and Mcdonald Islands",
  "VA": "Holy See (Vatican City State)",
  "HN": "Honduras",
  "HK": "Hong Kong",
  "HU": "Hungary",
  "IS": "Iceland",
  "IN": "India",
  "ID": "Indonesia",
  "IR": "Iran, Islamic Republic Of",
  "IQ": "Iraq",
  "IE": "Ireland",
  "IM": "Isle of Man",
  "IL": "Israel",
  "IT": "Italy",
  "JM": "Jamaica",
  "JP": "Japan",
  "JE": "Jersey",
  "JO": "Jordan",
  "KZ": "Kazakhstan",
  "KE": "Kenya",
  "KI": "Kiribati",
  "KP": "Korea, Democratic People\'S Republic of",
  "KR": "Korea, Republic of",
  "KW": "Kuwait",
  "KG": "Kyrgyzstan",
  "LA": "Lao People\'S Democratic Republic",
  "LV": "Latvia",
  "LB": "Lebanon",
  "LS": "Lesotho",
  "LR": "Liberia",
  "LY": "Libyan Arab Jamahiriya",
  "LI": "Liechtenstein",
  "LT": "Lithuania",
  "LU": "Luxembourg",
  "MO": "Macao",
  "MK": "Macedonia, The Former Yugoslav Republic of",
  "MG": "Madagascar",
  "MW": "Malawi",
  "MY": "Malaysia",
  "MV": "Maldives",
  "ML": "Mali",
  "MT": "Malta",
  "MH": "Marshall Islands",
  "MQ": "Martinique",
  "MR": "Mauritania",
  "MU": "Mauritius",
  "YT": "Mayotte",
  "MX": "Mexico",
  "FM": "Micronesia, Federated States of",
  "MD": "Moldova, Republic of",
  "MC": "Monaco",
  "MN": "Mongolia",
  "MS": "Montserrat",
  "MA": "Morocco",
  "MZ": "Mozambique",
  "MM": "Myanmar",
  "NA": "Namibia",
  "NR": "Nauru",
  "NP": "Nepal",
  "NL": "Netherlands",
  "AN": "Netherlands Antilles",
  "NC": "New Caledonia",
  "NZ": "New Zealand",
  "NI": "Nicaragua",
  "NE": "Niger",
  "NG": "Nigeria",
  "NU": "Niue",
  "NF": "Norfolk Island",
  "MP": "Northern Mariana Islands",
  "NO": "Norway",
  "OM": "Oman",
  "PK": "Pakistan",
  "PW": "Palau",
  "PS": "Palestinian Territory, Occupied",
  "PA": "Panama",
  "PG": "Papua New Guinea",
  "PY": "Paraguay",
  "PE": "Peru",
  "PH": "Philippines",
  "PN": "Pitcairn",
  "PL": "Poland",
  "PT": "Portugal",
  "PR": "Puerto Rico",
  "QA": "Qatar",
  "RE": "Reunion",
  "RO": "Romania",
  "RU": "Russian Federation",
  "RW": "RWANDA",
  "SH": "Saint Helena",
  "KN": "Saint Kitts and Nevis",
  "LC": "Saint Lucia",
  "PM": "Saint Pierre and Miquelon",
  "VC": "Saint Vincent and the Grenadines",
  "WS": "Samoa",
  "SM": "San Marino",
  "ST": "Sao Tome and Principe",
  "SA": "Saudi Arabia",
  "SN": "Senegal",
  "CS": "Serbia and Montenegro",
  "SC": "Seychelles",
  "SL": "Sierra Leone",
  "SG": "Singapore",
  "SK": "Slovakia",
  "SI": "Slovenia",
  "SB": "Solomon Islands",
  "SO": "Somalia",
  "ZA": "South Africa",
  "GS": "South Georgia and the South Sandwich Islands",
  "ES": "Spain",
  "LK": "Sri Lanka",
  "SD": "Sudan",
  "SR": "Suriname",
  "SJ": "Svalbard and Jan Mayen",
  "SZ": "Swaziland",
  "SE": "Sweden",
  "CH": "Switzerland",
  "SY": "Syrian Arab Republic",
  "TW": "Taiwan, Province of China",
  "TJ": "Tajikistan",
  "TZ": "Tanzania, United Republic of",
  "TH": "Thailand",
  "TL": "Timor-Leste",
  "TG": "Togo",
  "TK": "Tokelau",
  "TO": "Tonga",
  "TT": "Trinidad and Tobago",
  "TN": "Tunisia",
  "TR": "Turkey",
  "TM": "Turkmenistan",
  "TC": "Turks and Caicos Islands",
  "TV": "Tuvalu",
  "UG": "Uganda",
  "UA": "Ukraine",
  "AE": "United Arab Emirates",
  "GB": "United Kingdom",
  "UM": "United States Minor Outlying Islands",
  "UY": "Uruguay",
  "UZ": "Uzbekistan",
  "VU": "Vanuatu",
  "VE": "Venezuela",
  "VN": "Viet Nam",
  "VG": "Virgin Islands, British",
  "VI": "Virgin Islands, U.S.",
  "WF": "Wallis and Futuna",
  "EH": "Western Sahara",
  "YE": "Yemen",
  "ZM": "Zambia",
  "ZW": "Zimbabwe",
  string: undefined
};

const creditCardPaymentElementCss = ":host{display:block}:host .text-input{width:100%}:host .payment-row{display:flex;gap:var(--spacing-small)}:host .text-input .half{width:50%}";

const MadPaymentCreditCardPaymentElement$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.cardData = {
      complete: false,
      invalid: false,
      invalidFields: []
    };
  }
  componentDidLoad() {
    if (this.countrySelect) {
      this.countrySelect.setOptions(COUNTRIES);
    }
  }
  handleElementUpdate(e, elementType) {
    const { detail } = e;
    switch (elementType) {
      case ElementType.CREDIT_CARD_NUMBER:
        let cardEvent = detail;
        if (cardEvent.cardType && cardEvent.cardType.length === 1)
          this.cardData.cardBrand = cardEvent.cardType[0];
        this.cardData.cardNumber = cardEvent.value;
        break;
      case ElementType.SECURITY_CODE:
        this.cardData.cardSecurityCode = detail.value;
        break;
      default:
        console.log('fall through');
    }
  }
  render() {
    return (h(Host, null, h("div", { class: "payment-row" }, h("mad-payment-input", { placeholder: "John Doe", label: "Cardholer name", class: "text-input", name: "Name" })), h("div", { class: "payment-row" }, h("mad-payment-card-input", { class: "text-input", label: "Card Number", placeholder: "0000 0000 0000 0000", id: "card", onUpdate: (e) => this.handleElementUpdate(e, ElementType.CREDIT_CARD_NUMBER) })), h("div", { class: "payment-row" }, h("mad-payment-expiration-input", { label: "Expiration", placeholder: "01 / 22", class: "text-input half" }), h("mad-payment-cvv-input", { placeholder: "123", label: "Security Code", class: "text-input half", name: "security-code", max: 4, id: "security-code", onUpdate: (e) => this.handleElementUpdate(e, ElementType.SECURITY_CODE) })), h("div", { class: "payment-row" }, h("mad-payment-select", { label: "Country", id: "select", class: "text-input half", ref: el => this.countrySelect = el }), h("mad-payment-input", { placeholder: "33714", label: "Zipcode", class: "text-input half", name: "zipcode", max: 5 }))));
  }
  get element() { return this; }
  static get style() { return creditCardPaymentElementCss; }
}, [1, "mad-payment-credit-card-payment-element", {
    "cardData": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mad-payment-credit-card-payment-element", "mad-payment-card-input", "mad-payment-cvv-input", "mad-payment-expiration-input", "mad-payment-icon", "mad-payment-icon-amex", "mad-payment-icon-discover", "mad-payment-icon-mastercard", "mad-payment-icon-security-code", "mad-payment-icon-visa", "mad-payment-input", "mad-payment-select"];
  components.forEach(tagName => { switch (tagName) {
    case "mad-payment-credit-card-payment-element":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MadPaymentCreditCardPaymentElement$1);
      }
      break;
    case "mad-payment-card-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "mad-payment-cvv-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "mad-payment-expiration-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "mad-payment-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "mad-payment-icon-amex":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "mad-payment-icon-discover":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "mad-payment-icon-mastercard":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "mad-payment-icon-security-code":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "mad-payment-icon-visa":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "mad-payment-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "mad-payment-select":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MadPaymentCreditCardPaymentElement = MadPaymentCreditCardPaymentElement$1;
const defineCustomElement = defineCustomElement$1;

export { MadPaymentCreditCardPaymentElement, defineCustomElement };
